Class: OpenFga::Assertion

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/assertion.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Assertion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/openfga/models/assertion.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::Assertion` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::Assertion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tuple_key')
    self.tuple_key = attributes[:'tuple_key']
  else
    self.tuple_key = nil
  end

  if attributes.key?(:'expectation')
    self.expectation = attributes[:'expectation']
  else
    self.expectation = nil
  end

  if attributes.key?(:'contextual_tuples')
    if (value = attributes[:'contextual_tuples']).is_a?(Array)
      self.contextual_tuples = value
    end
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end
end

Instance Attribute Details

#contextObject

Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation.



26
27
28
# File 'lib/openfga/models/assertion.rb', line 26

def context
  @context
end

#contextual_tuplesObject

Returns the value of attribute contextual_tuples.



23
24
25
# File 'lib/openfga/models/assertion.rb', line 23

def contextual_tuples
  @contextual_tuples
end

#expectationObject

Returns the value of attribute expectation.



21
22
23
# File 'lib/openfga/models/assertion.rb', line 21

def expectation
  @expectation
end

#tuple_keyObject

Returns the value of attribute tuple_key.



19
20
21
# File 'lib/openfga/models/assertion.rb', line 19

def tuple_key
  @tuple_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



39
40
41
# File 'lib/openfga/models/assertion.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/openfga/models/assertion.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/openfga/models/assertion.rb', line 29

def self.attribute_map
  {
    'tuple_key': :'tuple_key',
    'expectation': :'expectation',
    'contextual_tuples': :'contextual_tuples',
    'context': :'context'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/openfga/models/assertion.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/openfga/models/assertion.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
# File 'lib/openfga/models/assertion.rb', line 49

def self.openapi_types
  {
    'tuple_key': :'AssertionTupleKey',
    'expectation': :'Boolean',
    'contextual_tuples': :'Array<TupleKey>',
    'context': :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
# File 'lib/openfga/models/assertion.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tuple_key == o.tuple_key &&
      expectation == o.expectation &&
      contextual_tuples == o.contextual_tuples &&
      context == o.context
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/openfga/models/assertion.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/openfga/models/assertion.rb', line 186

def hash
  [tuple_key, expectation, contextual_tuples, context].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/openfga/models/assertion.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @tuple_key.nil?
    invalid_properties.push('invalid value for "tuple_key", tuple_key cannot be nil.')
  end

  if @expectation.nil?
    invalid_properties.push('invalid value for "expectation", expectation cannot be nil.')
  end

  if !@contextual_tuples.nil? && @contextual_tuples.length > 20
    invalid_properties.push('invalid value for "contextual_tuples", number of items must be less than or equal to 20.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/openfga/models/assertion.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
129
130
131
# File 'lib/openfga/models/assertion.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @tuple_key.nil?
  return false if @expectation.nil?
  return false if !@contextual_tuples.nil? && @contextual_tuples.length > 20
  true
end