Class: OpenFga::BatchCheckRequest

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/batch_check_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BatchCheckRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/openfga/models/batch_check_request.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::BatchCheckRequest` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::BatchCheckRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'checks')
    if (value = attributes[:'checks']).is_a?(Array)
      self.checks = value
    end
  else
    self.checks = nil
  end

  if attributes.key?(:'authorization_model_id')
    self.authorization_model_id = attributes[:'authorization_model_id']
  end

  if attributes.key?(:'consistency')
    self.consistency = attributes[:'consistency']
  else
    self.consistency = 'UNSPECIFIED'
  end
end

Instance Attribute Details

#authorization_model_idObject

Returns the value of attribute authorization_model_id.



21
22
23
# File 'lib/openfga/models/batch_check_request.rb', line 21

def authorization_model_id
  @authorization_model_id
end

#checksObject

Returns the value of attribute checks.



19
20
21
# File 'lib/openfga/models/batch_check_request.rb', line 19

def checks
  @checks
end

#consistencyObject

Returns the value of attribute consistency.



23
24
25
# File 'lib/openfga/models/batch_check_request.rb', line 23

def consistency
  @consistency
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/openfga/models/batch_check_request.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/openfga/models/batch_check_request.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/openfga/models/batch_check_request.rb', line 48

def self.attribute_map
  {
    'checks': :'checks',
    'authorization_model_id': :'authorization_model_id',
    'consistency': :'consistency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/openfga/models/batch_check_request.rb', line 180

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/openfga/models/batch_check_request.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/openfga/models/batch_check_request.rb', line 67

def self.openapi_types
  {
    'checks': :'Array<BatchCheckItem>',
    'authorization_model_id': :'String',
    'consistency': :'ConsistencyPreference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



157
158
159
160
161
162
163
# File 'lib/openfga/models/batch_check_request.rb', line 157

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      checks == o.checks &&
      authorization_model_id == o.authorization_model_id &&
      consistency == o.consistency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/openfga/models/batch_check_request.rb', line 167

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



173
174
175
# File 'lib/openfga/models/batch_check_request.rb', line 173

def hash
  [checks, authorization_model_id, consistency].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/openfga/models/batch_check_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @checks.nil?
    invalid_properties.push('invalid value for "checks", checks cannot be nil.')
  end

  if @checks.length < 1
    invalid_properties.push('invalid value for "checks", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/openfga/models/batch_check_request.rb', line 202

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
# File 'lib/openfga/models/batch_check_request.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @checks.nil?
  return false if @checks.length < 1
  true
end