Class: OpenFga::CheckError

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/check_error.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CheckError

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/openfga/models/check_error.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::CheckError` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::CheckError`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'input_error')
    self.input_error = attributes[:'input_error']
  else
    self.input_error = 'no_error'
  end

  if attributes.key?(:'internal_error')
    self.internal_error = attributes[:'internal_error']
  else
    self.internal_error = 'no_internal_error'
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end
end

Instance Attribute Details

#input_errorObject

Returns the value of attribute input_error.



19
20
21
# File 'lib/openfga/models/check_error.rb', line 19

def input_error
  @input_error
end

#internal_errorObject

Returns the value of attribute internal_error.



21
22
23
# File 'lib/openfga/models/check_error.rb', line 21

def internal_error
  @internal_error
end

#messageObject

Returns the value of attribute message.



23
24
25
# File 'lib/openfga/models/check_error.rb', line 23

def message
  @message
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/openfga/models/check_error.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/openfga/models/check_error.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/openfga/models/check_error.rb', line 48

def self.attribute_map
  {
    'input_error': :'input_error',
    'internal_error': :'internal_error',
    'message': :'message'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/openfga/models/check_error.rb', line 154

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/openfga/models/check_error.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/openfga/models/check_error.rb', line 67

def self.openapi_types
  {
    'input_error': :'ErrorCode',
    'internal_error': :'InternalErrorCode',
    'message': :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
# File 'lib/openfga/models/check_error.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      input_error == o.input_error &&
      internal_error == o.internal_error &&
      message == o.message
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


141
142
143
# File 'lib/openfga/models/check_error.rb', line 141

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



147
148
149
# File 'lib/openfga/models/check_error.rb', line 147

def hash
  [input_error, internal_error, message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
# File 'lib/openfga/models/check_error.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/openfga/models/check_error.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
# File 'lib/openfga/models/check_error.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end