Class: OpenFga::CheckRequestTupleKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenFga::CheckRequestTupleKey
- Defined in:
- lib/openfga/models/check_request_tuple_key.rb
Instance Attribute Summary collapse
-
#object ⇒ Object
Returns the value of attribute object.
-
#relation ⇒ Object
Returns the value of attribute relation.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckRequestTupleKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CheckRequestTupleKey
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::CheckRequestTupleKey` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::CheckRequestTupleKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user') self.user = attributes[:'user'] else self.user = nil end if attributes.key?(:'relation') self.relation = attributes[:'relation'] else self.relation = nil end if attributes.key?(:'object') self.object = attributes[:'object'] else self.object = nil end end |
Instance Attribute Details
#object ⇒ Object
Returns the value of attribute object.
23 24 25 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 23 def object @object end |
#relation ⇒ Object
Returns the value of attribute relation.
21 22 23 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 21 def relation @relation end |
#user ⇒ Object
Returns the value of attribute user.
19 20 21 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 19 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 26 def self.attribute_map { 'user': :'user', 'relation': :'relation', 'object': :'object' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 206 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 54 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 45 def self.openapi_types { 'user': :'String', 'relation': :'String', 'object': :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && user == o.user && relation == o.relation && object == o.object end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 199 def hash [user, relation, object].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end if @user.to_s.length > 512 invalid_properties.push('invalid value for "user", the character length must be smaller than or equal to 512.') end if @relation.nil? invalid_properties.push('invalid value for "relation", relation cannot be nil.') end if @relation.to_s.length > 50 invalid_properties.push('invalid value for "relation", the character length must be smaller than or equal to 50.') end if @object.nil? invalid_properties.push('invalid value for "object", object cannot be nil.') end if @object.to_s.length > 256 invalid_properties.push('invalid value for "object", the character length must be smaller than or equal to 256.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 133 134 135 136 137 |
# File 'lib/openfga/models/check_request_tuple_key.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @user.nil? return false if @user.to_s.length > 512 return false if @relation.nil? return false if @relation.to_s.length > 50 return false if @object.nil? return false if @object.to_s.length > 256 true end |