Class: OpenFga::ListObjectsRequest

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/list_objects_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListObjectsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/openfga/models/list_objects_request.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::ListObjectsRequest` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::ListObjectsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'relation')
    self.relation = attributes[:'relation']
  else
    self.relation = nil
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'authorization_model_id')
    self.authorization_model_id = attributes[:'authorization_model_id']
  end

  if attributes.key?(:'contextual_tuples')
    self.contextual_tuples = attributes[:'contextual_tuples']
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'consistency')
    self.consistency = attributes[:'consistency']
  else
    self.consistency = 'UNSPECIFIED'
  end
end

Instance Attribute Details

#authorization_model_idObject

Returns the value of attribute authorization_model_id.



25
26
27
# File 'lib/openfga/models/list_objects_request.rb', line 25

def authorization_model_id
  @authorization_model_id
end

#consistencyObject

Returns the value of attribute consistency.



32
33
34
# File 'lib/openfga/models/list_objects_request.rb', line 32

def consistency
  @consistency
end

#contextObject

Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation.



30
31
32
# File 'lib/openfga/models/list_objects_request.rb', line 30

def context
  @context
end

#contextual_tuplesObject

Returns the value of attribute contextual_tuples.



27
28
29
# File 'lib/openfga/models/list_objects_request.rb', line 27

def contextual_tuples
  @contextual_tuples
end

#relationObject

Returns the value of attribute relation.



21
22
23
# File 'lib/openfga/models/list_objects_request.rb', line 21

def relation
  @relation
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/openfga/models/list_objects_request.rb', line 19

def type
  @type
end

#userObject

Returns the value of attribute user.



23
24
25
# File 'lib/openfga/models/list_objects_request.rb', line 23

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/openfga/models/list_objects_request.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/openfga/models/list_objects_request.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/openfga/models/list_objects_request.rb', line 57

def self.attribute_map
  {
    'type': :'type',
    'relation': :'relation',
    'user': :'user',
    'authorization_model_id': :'authorization_model_id',
    'contextual_tuples': :'contextual_tuples',
    'context': :'context',
    'consistency': :'consistency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/openfga/models/list_objects_request.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/openfga/models/list_objects_request.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/openfga/models/list_objects_request.rb', line 80

def self.openapi_types
  {
    'type': :'String',
    'relation': :'String',
    'user': :'String',
    'authorization_model_id': :'String',
    'contextual_tuples': :'ContextualTupleKeys',
    'context': :'Object',
    'consistency': :'ConsistencyPreference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
# File 'lib/openfga/models/list_objects_request.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      relation == o.relation &&
      user == o.user &&
      authorization_model_id == o.authorization_model_id &&
      contextual_tuples == o.contextual_tuples &&
      context == o.context &&
      consistency == o.consistency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/openfga/models/list_objects_request.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/openfga/models/list_objects_request.rb', line 251

def hash
  [type, relation, user, authorization_model_id, contextual_tuples, context, consistency].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/openfga/models/list_objects_request.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @relation.nil?
    invalid_properties.push('invalid value for "relation", relation cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @user.to_s.length > 512
    invalid_properties.push('invalid value for "user", the character length must be smaller than or equal to 512.')
  end

  if @user.to_s.length < 1
    invalid_properties.push('invalid value for "user", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/openfga/models/list_objects_request.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
# File 'lib/openfga/models/list_objects_request.rb', line 181

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  return false if @relation.nil?
  return false if @user.nil?
  return false if @user.to_s.length > 512
  return false if @user.to_s.length < 1
  true
end