Class: OpenFga::ListUsersRequest

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/list_users_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListUsersRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/openfga/models/list_users_request.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::ListUsersRequest` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::ListUsersRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'relation')
    self.relation = attributes[:'relation']
  else
    self.relation = nil
  end

  if attributes.key?(:'user_filters')
    if (value = attributes[:'user_filters']).is_a?(Array)
      self.user_filters = value
    end
  else
    self.user_filters = nil
  end

  if attributes.key?(:'authorization_model_id')
    self.authorization_model_id = attributes[:'authorization_model_id']
  end

  if attributes.key?(:'contextual_tuples')
    if (value = attributes[:'contextual_tuples']).is_a?(Array)
      self.contextual_tuples = value
    end
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'consistency')
    self.consistency = attributes[:'consistency']
  else
    self.consistency = 'UNSPECIFIED'
  end
end

Instance Attribute Details

#authorization_model_idObject

Returns the value of attribute authorization_model_id.



26
27
28
# File 'lib/openfga/models/list_users_request.rb', line 26

def authorization_model_id
  @authorization_model_id
end

#consistencyObject

Returns the value of attribute consistency.



33
34
35
# File 'lib/openfga/models/list_users_request.rb', line 33

def consistency
  @consistency
end

#contextObject

Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation.



31
32
33
# File 'lib/openfga/models/list_users_request.rb', line 31

def context
  @context
end

#contextual_tuplesObject

Returns the value of attribute contextual_tuples.



28
29
30
# File 'lib/openfga/models/list_users_request.rb', line 28

def contextual_tuples
  @contextual_tuples
end

#objectObject

Returns the value of attribute object.



19
20
21
# File 'lib/openfga/models/list_users_request.rb', line 19

def object
  @object
end

#relationObject

Returns the value of attribute relation.



21
22
23
# File 'lib/openfga/models/list_users_request.rb', line 21

def relation
  @relation
end

#user_filtersObject

The type of results returned. Only accepts exactly one value.



24
25
26
# File 'lib/openfga/models/list_users_request.rb', line 24

def user_filters
  @user_filters
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/openfga/models/list_users_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/openfga/models/list_users_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/openfga/models/list_users_request.rb', line 58

def self.attribute_map
  {
    'object': :'object',
    'relation': :'relation',
    'user_filters': :'user_filters',
    'authorization_model_id': :'authorization_model_id',
    'contextual_tuples': :'contextual_tuples',
    'context': :'context',
    'consistency': :'consistency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/openfga/models/list_users_request.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/openfga/models/list_users_request.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/openfga/models/list_users_request.rb', line 81

def self.openapi_types
  {
    'object': :'FgaObject',
    'relation': :'String',
    'user_filters': :'Array<UserTypeFilter>',
    'authorization_model_id': :'String',
    'contextual_tuples': :'Array<TupleKey>',
    'context': :'Object',
    'consistency': :'ConsistencyPreference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



255
256
257
258
259
260
261
262
263
264
265
# File 'lib/openfga/models/list_users_request.rb', line 255

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object == o.object &&
      relation == o.relation &&
      user_filters == o.user_filters &&
      authorization_model_id == o.authorization_model_id &&
      contextual_tuples == o.contextual_tuples &&
      context == o.context &&
      consistency == o.consistency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/openfga/models/list_users_request.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/openfga/models/list_users_request.rb', line 275

def hash
  [object, relation, user_filters, authorization_model_id, contextual_tuples, context, consistency].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/openfga/models/list_users_request.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @relation.nil?
    invalid_properties.push('invalid value for "relation", relation cannot be nil.')
  end

  if @user_filters.nil?
    invalid_properties.push('invalid value for "user_filters", user_filters cannot be nil.')
  end

  if @user_filters.length > 1
    invalid_properties.push('invalid value for "user_filters", number of items must be less than or equal to 1.')
  end

  if @user_filters.length < 1
    invalid_properties.push('invalid value for "user_filters", number of items must be greater than or equal to 1.')
  end

  if !@contextual_tuples.nil? && @contextual_tuples.length > 100
    invalid_properties.push('invalid value for "contextual_tuples", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/openfga/models/list_users_request.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
# File 'lib/openfga/models/list_users_request.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object.nil?
  return false if @relation.nil?
  return false if @user_filters.nil?
  return false if @user_filters.length > 1
  return false if @user_filters.length < 1
  return false if !@contextual_tuples.nil? && @contextual_tuples.length > 100
  true
end