Class: OpenFga::Node

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/node.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Node

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/openfga/models/node.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::Node` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::Node`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'leaf')
    self.leaf = attributes[:'leaf']
  end

  if attributes.key?(:'difference')
    self.difference = attributes[:'difference']
  end

  if attributes.key?(:'union')
    self.union = attributes[:'union']
  end

  if attributes.key?(:'intersection')
    self.intersection = attributes[:'intersection']
  end
end

Instance Attribute Details

#differenceObject

Returns the value of attribute difference.



23
24
25
# File 'lib/openfga/models/node.rb', line 23

def difference
  @difference
end

#intersectionObject

Returns the value of attribute intersection.



27
28
29
# File 'lib/openfga/models/node.rb', line 27

def intersection
  @intersection
end

#leafObject

Returns the value of attribute leaf.



21
22
23
# File 'lib/openfga/models/node.rb', line 21

def leaf
  @leaf
end

#nameObject

Returns the value of attribute name.



19
20
21
# File 'lib/openfga/models/node.rb', line 19

def name
  @name
end

#unionObject

Returns the value of attribute union.



25
26
27
# File 'lib/openfga/models/node.rb', line 25

def union
  @union
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/openfga/models/node.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/openfga/models/node.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
# File 'lib/openfga/models/node.rb', line 30

def self.attribute_map
  {
    'name': :'name',
    'leaf': :'leaf',
    'difference': :'difference',
    'union': :'union',
    'intersection': :'intersection'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/openfga/models/node.rb', line 163

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/openfga/models/node.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
# File 'lib/openfga/models/node.rb', line 51

def self.openapi_types
  {
    'name': :'String',
    'leaf': :'Leaf',
    'difference': :'UsersetTreeDifference',
    'union': :'Nodes',
    'intersection': :'Nodes'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



138
139
140
141
142
143
144
145
146
# File 'lib/openfga/models/node.rb', line 138

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      leaf == o.leaf &&
      difference == o.difference &&
      union == o.union &&
      intersection == o.intersection
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


150
151
152
# File 'lib/openfga/models/node.rb', line 150

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



156
157
158
# File 'lib/openfga/models/node.rb', line 156

def hash
  [name, leaf, difference, union, intersection].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
# File 'lib/openfga/models/node.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/openfga/models/node.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



120
121
122
123
124
# File 'lib/openfga/models/node.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end