Class: OpenFga::ReadRequest

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/read_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReadRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/openfga/models/read_request.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::ReadRequest` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::ReadRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tuple_key')
    self.tuple_key = attributes[:'tuple_key']
  end

  if attributes.key?(:'page_size')
    self.page_size = attributes[:'page_size']
  end

  if attributes.key?(:'continuation_token')
    self.continuation_token = attributes[:'continuation_token']
  end

  if attributes.key?(:'consistency')
    self.consistency = attributes[:'consistency']
  else
    self.consistency = 'UNSPECIFIED'
  end
end

Instance Attribute Details

#consistencyObject

Returns the value of attribute consistency.



25
26
27
# File 'lib/openfga/models/read_request.rb', line 25

def consistency
  @consistency
end

#continuation_tokenObject

Returns the value of attribute continuation_token.



23
24
25
# File 'lib/openfga/models/read_request.rb', line 23

def continuation_token
  @continuation_token
end

#page_sizeObject

Returns the value of attribute page_size.



21
22
23
# File 'lib/openfga/models/read_request.rb', line 21

def page_size
  @page_size
end

#tuple_keyObject

Returns the value of attribute tuple_key.



19
20
21
# File 'lib/openfga/models/read_request.rb', line 19

def tuple_key
  @tuple_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/openfga/models/read_request.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/openfga/models/read_request.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
# File 'lib/openfga/models/read_request.rb', line 50

def self.attribute_map
  {
    'tuple_key': :'tuple_key',
    'page_size': :'page_size',
    'continuation_token': :'continuation_token',
    'consistency': :'consistency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/openfga/models/read_request.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/openfga/models/read_request.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
# File 'lib/openfga/models/read_request.rb', line 70

def self.openapi_types
  {
    'tuple_key': :'ReadRequestTupleKey',
    'page_size': :'Integer',
    'continuation_token': :'String',
    'consistency': :'ConsistencyPreference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
# File 'lib/openfga/models/read_request.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tuple_key == o.tuple_key &&
      page_size == o.page_size &&
      continuation_token == o.continuation_token &&
      consistency == o.consistency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/openfga/models/read_request.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/openfga/models/read_request.rb', line 182

def hash
  [tuple_key, page_size, continuation_token, consistency].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/openfga/models/read_request.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@page_size.nil? && @page_size > 100
    invalid_properties.push('invalid value for "page_size", must be smaller than or equal to 100.')
  end

  if !@page_size.nil? && @page_size < 1
    invalid_properties.push('invalid value for "page_size", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/openfga/models/read_request.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
143
# File 'lib/openfga/models/read_request.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@page_size.nil? && @page_size > 100
  return false if !@page_size.nil? && @page_size < 1
  true
end