Class: OpenFga::TokenManager::NoopTokenManager

Inherits:
Object
  • Object
show all
Defined in:
lib/openfga/token_manager/token_manager.rb

Overview

NoopTokenManager just returns a nil token. Looks redundant but makes usage code easier as we don’t have to have special case code when we want an access token if authorization is not configured.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeNoopTokenManager

Returns a new instance of NoopTokenManager.



18
19
20
# File 'lib/openfga/token_manager/token_manager.rb', line 18

def initialize
  @access_token = nil
end

Instance Attribute Details

#access_tokenObject (readonly)

Returns the value of attribute access_token.



17
18
19
# File 'lib/openfga/token_manager/token_manager.rb', line 17

def access_token
  @access_token
end