Class: OpenFga::TupleKey

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/tuple_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TupleKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/openfga/models/tuple_key.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::TupleKey` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::TupleKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'relation')
    self.relation = attributes[:'relation']
  else
    self.relation = nil
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  else
    self.object = nil
  end

  if attributes.key?(:'condition')
    self.condition = attributes[:'condition']
  end
end

Instance Attribute Details

#conditionObject

Returns the value of attribute condition.



25
26
27
# File 'lib/openfga/models/tuple_key.rb', line 25

def condition
  @condition
end

#objectObject

Returns the value of attribute object.



23
24
25
# File 'lib/openfga/models/tuple_key.rb', line 23

def object
  @object
end

#relationObject

Returns the value of attribute relation.



21
22
23
# File 'lib/openfga/models/tuple_key.rb', line 21

def relation
  @relation
end

#userObject

Returns the value of attribute user.



19
20
21
# File 'lib/openfga/models/tuple_key.rb', line 19

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/openfga/models/tuple_key.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/openfga/models/tuple_key.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
# File 'lib/openfga/models/tuple_key.rb', line 28

def self.attribute_map
  {
    'user': :'user',
    'relation': :'relation',
    'object': :'object',
    'condition': :'condition'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/openfga/models/tuple_key.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
# File 'lib/openfga/models/tuple_key.rb', line 58

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
# File 'lib/openfga/models/tuple_key.rb', line 48

def self.openapi_types
  {
    'user': :'String',
    'relation': :'String',
    'object': :'String',
    'condition': :'RelationshipCondition'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
# File 'lib/openfga/models/tuple_key.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      user == o.user &&
      relation == o.relation &&
      object == o.object &&
      condition == o.condition
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/openfga/models/tuple_key.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/openfga/models/tuple_key.rb', line 208

def hash
  [user, relation, object, condition].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/openfga/models/tuple_key.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @user.to_s.length > 512
    invalid_properties.push('invalid value for "user", the character length must be smaller than or equal to 512.')
  end

  if @relation.nil?
    invalid_properties.push('invalid value for "relation", relation cannot be nil.')
  end

  if @relation.to_s.length > 50
    invalid_properties.push('invalid value for "relation", the character length must be smaller than or equal to 50.')
  end

  if @object.nil?
    invalid_properties.push('invalid value for "object", object cannot be nil.')
  end

  if @object.to_s.length > 256
    invalid_properties.push('invalid value for "object", the character length must be smaller than or equal to 256.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/openfga/models/tuple_key.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
139
140
141
142
143
144
145
# File 'lib/openfga/models/tuple_key.rb', line 136

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @user.nil?
  return false if @user.to_s.length > 512
  return false if @relation.nil?
  return false if @relation.to_s.length > 50
  return false if @object.nil?
  return false if @object.to_s.length > 256
  true
end