Class: OpenFga::Userset

Inherits:
ApiModelBase show all
Defined in:
lib/openfga/models/userset.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Userset

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/openfga/models/userset.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::Userset` initialize method'
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::Userset`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'this')
    self.this = attributes[:'this']
  end

  if attributes.key?(:'computed_userset')
    self.computed_userset = attributes[:'computed_userset']
  end

  if attributes.key?(:'tuple_to_userset')
    self.tuple_to_userset = attributes[:'tuple_to_userset']
  end

  if attributes.key?(:'union')
    self.union = attributes[:'union']
  end

  if attributes.key?(:'intersection')
    self.intersection = attributes[:'intersection']
  end

  if attributes.key?(:'difference')
    self.difference = attributes[:'difference']
  end
end

Instance Attribute Details

#computed_usersetObject

Returns the value of attribute computed_userset.



22
23
24
# File 'lib/openfga/models/userset.rb', line 22

def computed_userset
  @computed_userset
end

#differenceObject

Returns the value of attribute difference.



30
31
32
# File 'lib/openfga/models/userset.rb', line 30

def difference
  @difference
end

#intersectionObject

Returns the value of attribute intersection.



28
29
30
# File 'lib/openfga/models/userset.rb', line 28

def intersection
  @intersection
end

#thisObject

A DirectUserset is a sentinel message for referencing the direct members specified by an object/relation mapping.



20
21
22
# File 'lib/openfga/models/userset.rb', line 20

def this
  @this
end

#tuple_to_usersetObject

Returns the value of attribute tuple_to_userset.



24
25
26
# File 'lib/openfga/models/userset.rb', line 24

def tuple_to_userset
  @tuple_to_userset
end

#unionObject

Returns the value of attribute union.



26
27
28
# File 'lib/openfga/models/userset.rb', line 26

def union
  @union
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/openfga/models/userset.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/openfga/models/userset.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/openfga/models/userset.rb', line 33

def self.attribute_map
  {
    'this': :'this',
    'computed_userset': :'computedUserset',
    'tuple_to_userset': :'tupleToUserset',
    'union': :'union',
    'intersection': :'intersection',
    'difference': :'difference'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/openfga/models/userset.rb', line 156

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/openfga/models/userset.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/openfga/models/userset.rb', line 55

def self.openapi_types
  {
    'this': :'Object',
    'computed_userset': :'ObjectRelation',
    'tuple_to_userset': :'TupleToUserset',
    'union': :'Usersets',
    'intersection': :'Usersets',
    'difference': :'Difference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



130
131
132
133
134
135
136
137
138
139
# File 'lib/openfga/models/userset.rb', line 130

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      this == o.this &&
      computed_userset == o.computed_userset &&
      tuple_to_userset == o.tuple_to_userset &&
      union == o.union &&
      intersection == o.intersection &&
      difference == o.difference
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


143
144
145
# File 'lib/openfga/models/userset.rb', line 143

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



149
150
151
# File 'lib/openfga/models/userset.rb', line 149

def hash
  [this, computed_userset, tuple_to_userset, union, intersection, difference].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
# File 'lib/openfga/models/userset.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/openfga/models/userset.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
# File 'lib/openfga/models/userset.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end