Class: OpenFga::CheckRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenFga::CheckRequest
- Defined in:
- lib/openfga/models/check_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authorization_model_id ⇒ Object
Returns the value of attribute authorization_model_id.
-
#consistency ⇒ Object
Returns the value of attribute consistency.
-
#context ⇒ Object
Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation.
-
#contextual_tuples ⇒ Object
Returns the value of attribute contextual_tuples.
-
#trace ⇒ Object
Defaults to false.
-
#tuple_key ⇒ Object
Returns the value of attribute tuple_key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CheckRequest
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/openfga/models/check_request.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::CheckRequest` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::CheckRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tuple_key') self.tuple_key = attributes[:'tuple_key'] else self.tuple_key = nil end if attributes.key?(:'contextual_tuples') self.contextual_tuples = attributes[:'contextual_tuples'] end if attributes.key?(:'authorization_model_id') self. = attributes[:'authorization_model_id'] end if attributes.key?(:'trace') self.trace = attributes[:'trace'] end if attributes.key?(:'context') self.context = attributes[:'context'] end if attributes.key?(:'consistency') self.consistency = attributes[:'consistency'] else self.consistency = 'UNSPECIFIED' end end |
Instance Attribute Details
#authorization_model_id ⇒ Object
Returns the value of attribute authorization_model_id.
23 24 25 |
# File 'lib/openfga/models/check_request.rb', line 23 def @authorization_model_id end |
#consistency ⇒ Object
Returns the value of attribute consistency.
31 32 33 |
# File 'lib/openfga/models/check_request.rb', line 31 def consistency @consistency end |
#context ⇒ Object
Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation.
29 30 31 |
# File 'lib/openfga/models/check_request.rb', line 29 def context @context end |
#contextual_tuples ⇒ Object
Returns the value of attribute contextual_tuples.
21 22 23 |
# File 'lib/openfga/models/check_request.rb', line 21 def contextual_tuples @contextual_tuples end |
#trace ⇒ Object
Defaults to false. Making it true has performance implications.
26 27 28 |
# File 'lib/openfga/models/check_request.rb', line 26 def trace @trace end |
#tuple_key ⇒ Object
Returns the value of attribute tuple_key.
19 20 21 |
# File 'lib/openfga/models/check_request.rb', line 19 def tuple_key @tuple_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/openfga/models/check_request.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/openfga/models/check_request.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/openfga/models/check_request.rb', line 56 def self.attribute_map { 'tuple_key': :'tuple_key', 'contextual_tuples': :'contextual_tuples', 'authorization_model_id': :'authorization_model_id', 'trace': :'trace', 'context': :'context', 'consistency': :'consistency' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/openfga/models/check_request.rb', line 198 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/openfga/models/check_request.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/openfga/models/check_request.rb', line 78 def self.openapi_types { 'tuple_key': :'CheckRequestTupleKey', 'contextual_tuples': :'ContextualTupleKeys', 'authorization_model_id': :'String', 'trace': :'Boolean', 'context': :'Object', 'consistency': :'ConsistencyPreference' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/openfga/models/check_request.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && tuple_key == o.tuple_key && contextual_tuples == o.contextual_tuples && == o. && trace == o.trace && context == o.context && consistency == o.consistency end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/openfga/models/check_request.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/openfga/models/check_request.rb', line 191 def hash [tuple_key, contextual_tuples, , trace, context, consistency].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 |
# File 'lib/openfga/models/check_request.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @tuple_key.nil? invalid_properties.push('invalid value for "tuple_key", tuple_key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/openfga/models/check_request.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 158 |
# File 'lib/openfga/models/check_request.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @tuple_key.nil? true end |