Class: OpenFga::TokenManager::StaticTokenManager
- Inherits:
-
Object
- Object
- OpenFga::TokenManager::StaticTokenManager
- Defined in:
- lib/openfga/token_manager/token_manager.rb
Overview
StaticTokenManager just keeps a hold of and returns whatever token is given to the client by the caller, in case they’re using their own access token.
Instance Attribute Summary collapse
-
#access_token ⇒ Object
readonly
Returns the value of attribute access_token.
Instance Method Summary collapse
-
#initialize(access_token) ⇒ StaticTokenManager
constructor
A new instance of StaticTokenManager.
Constructor Details
#initialize(access_token) ⇒ StaticTokenManager
Returns a new instance of StaticTokenManager.
28 29 30 |
# File 'lib/openfga/token_manager/token_manager.rb', line 28 def initialize(access_token) @access_token = access_token end |
Instance Attribute Details
#access_token ⇒ Object (readonly)
Returns the value of attribute access_token.
26 27 28 |
# File 'lib/openfga/token_manager/token_manager.rb', line 26 def access_token @access_token end |