Class: OpenFga::WriteRequestWrites
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OpenFga::WriteRequestWrites
- Defined in:
- lib/openfga/models/write_request_writes.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#on_duplicate ⇒ Object
On ‘error’ ( or unspecified ), the API returns an error if an identical tuple already exists.
-
#tuple_keys ⇒ Object
Returns the value of attribute tuple_keys.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WriteRequestWrites
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WriteRequestWrites
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/openfga/models/write_request_writes.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, 'The input argument (attributes) must be a hash in `OpenFga::WriteRequestWrites` initialize method' end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenFga::WriteRequestWrites`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tuple_keys') if (value = attributes[:'tuple_keys']).is_a?(Array) self.tuple_keys = value end else self.tuple_keys = nil end if attributes.key?(:'on_duplicate') self.on_duplicate = attributes[:'on_duplicate'] else self.on_duplicate = 'error' end end |
Instance Attribute Details
#on_duplicate ⇒ Object
On ‘error’ ( or unspecified ), the API returns an error if an identical tuple already exists. On ‘ignore’, identical writes are treated as no-ops (matching on user, relation, object, and RelationshipCondition).
22 23 24 |
# File 'lib/openfga/models/write_request_writes.rb', line 22 def on_duplicate @on_duplicate end |
#tuple_keys ⇒ Object
Returns the value of attribute tuple_keys.
19 20 21 |
# File 'lib/openfga/models/write_request_writes.rb', line 19 def tuple_keys @tuple_keys end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/openfga/models/write_request_writes.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/openfga/models/write_request_writes.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 |
# File 'lib/openfga/models/write_request_writes.rb', line 47 def self.attribute_map { 'tuple_keys': :'tuple_keys', 'on_duplicate': :'on_duplicate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/openfga/models/write_request_writes.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/openfga/models/write_request_writes.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 |
# File 'lib/openfga/models/write_request_writes.rb', line 65 def self.openapi_types { 'tuple_keys': :'Array<TupleKey>', 'on_duplicate': :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 |
# File 'lib/openfga/models/write_request_writes.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && tuple_keys == o.tuple_keys && on_duplicate == o.on_duplicate end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/openfga/models/write_request_writes.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/openfga/models/write_request_writes.rb', line 177 def hash [tuple_keys, on_duplicate].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/openfga/models/write_request_writes.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @tuple_keys.nil? invalid_properties.push('invalid value for "tuple_keys", tuple_keys cannot be nil.') end if @tuple_keys.length < 1 invalid_properties.push('invalid value for "tuple_keys", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/openfga/models/write_request_writes.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 134 |
# File 'lib/openfga/models/write_request_writes.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @tuple_keys.nil? return false if @tuple_keys.length < 1 on_duplicate_validator = EnumAttributeValidator.new('String', ['error', 'ignore']) return false unless on_duplicate_validator.valid?(@on_duplicate) true end |